@@ -20,6 +20,18 @@ class Dict_:
         self.__dict = AttributDict(dictionary)
 
 
+    def __getitem__(self, item):
+        return self.__dict[item]
+
+    def __bool__(self):
+        return True if self.__dict else False
+
+    def __len__(self):
+        return len(self.__dict)
+
+    def __iter__(self):
+        return iter(self.__dict)
+
 
     def _check_types(self, value: dict) -> None:
         """
